# llm-api-router Development Guidelines

Auto-generated from all feature plans. Last updated: 2026-01-12

## Active Technologies
- Python >= 3.10 + httpx, pydantic (optional, using dataclasses primarily) (001-unified-api-router)

- (001-unified-api-router)

## Project Structure

```text
backend/
frontend/
tests/
```

## Commands

# Add commands for 

## Code Style

: Follow standard conventions

## Recent Changes
- 001-unified-api-router: Added Python >= 3.10 + httpx, pydantic (optional, using dataclasses primarily)

- 001-unified-api-router: Added

<!-- MANUAL ADDITIONS START -->
<!-- MANUAL ADDITIONS END -->
